/*******************************************************************************
*                                                                              *
*   NetBurner MOD5282 General Purpose Input/Output Header File                 *
*   gpio5282.h                                                                 *
*                                                                              *
*******************************************************************************/


////////////////////////////////////////////////////////////////////////////////
// GPIO Pin Assignment Register Definitions. All signals are referenced to their
// primary functions. Writing the complement of each of the following defined
// values associated with a signal in the register will configure the
// corresponding pin for GPIO.
//
// Note: There are no bit definitions listed in this section for the analog I/O
// (QADC) and external IRQ (EPORT) pins in this section; they are set to GPIO by
// default. Also, the general purpose timers do not have a pin assignment
// register; the GPTA and GPTB pins become configured for GPIO when the GPT
// functionality is disabled in the GPT System Control Register 1.
//

//
// For use with port E pin assignment register: sim.gpio.pepar.
//
#define GPIO_PAR_RW         ( 0x0100 )   // Bit       8 - Read / not Write
#define GPIO_PAR_OE         ( 0x4000 )   // Bit      14 - Output Enable
#define GPIO_PAR_TIP        ( 0x0003 )   // Bit  1 -  0 - Transfer in Progress
#define GPIO_PAR_TA         ( 0x1000 )   // Bit      12 - Transfer Acknowledge

//
// For use with port J pin assignment register: sim.gpio.pjpar.
//
#define GPIO_PAR_CS1        (   0x02 )   // Bit       1 - Chip Select #1
#define GPIO_PAR_CS2        (   0x04 )   // Bit       2 - Chip Select #2
#define GPIO_PAR_CS3        (   0x08 )   // Bit       3 - Chip Select #3

//
// For use with port UA pin assignment register: sim.gpio.puapar.
//
#define GPIO_PAR_URXD0      (   0x02 )   // Bit       1 - UART 0 - Receive
#define GPIO_PAR_UTXD0      (   0x01 )   // Bit       0 - UART 0 - Transmit
#define GPIO_PAR_URXD1      (   0x08 )   // Bit       3 - UART 1 - Receive
#define GPIO_PAR_UTXD1      (   0x04 )   // Bit       2 - UART 1 - Transmit

//
// For use with port QS pin assignment register: sim.gpio.pqspar.
//
#define GPIO_PAR_SPI_CLK    (   0x04 )   // Bit       2 - SPI Clock
#define GPIO_PAR_SPI_CS3    (   0x40 )   // Bit       6 - SPI Chip Select 3
#define GPIO_PAR_SPI_DIN    (   0x02 )   // Bit       1 - SPI Data In
#define GPIO_PAR_SPI_DOUT   (   0x01 )   // Bit       0 - SPI Data Out
#define GPIO_PAR_SPI_CS0    (   0x08 )   // Bit       3 - SPI Chip Select 0
#define GPIO_PAR_SPI_CS2    (   0x20 )   // Bit       5 - SPI Chip Select 2
#define GPIO_PAR_SPI_CS1    (   0x10 )   // Bit       4 - SPI Chip Select 1

//
// For use with port AS pin assignment register: sim.gpio.paspar.
//
#define GPIO_PAR_SDA        ( 0x000C )   // Bit  3 -  2 - I2C Serial Data
#define GPIO_PAR_CANRX      ( 0x00C0 )   // Bit  7 -  6 - CAN - Receive
#define GPIO_PAR_SCL        ( 0x0003 )   // Bit  1 -  0 - I2C Serial Clock
#define GPIO_PAR_CANTX      ( 0x0030 )   // Bit  5 -  4 - CAN - Transmit

//
// For use with port TC pin assignment register: sim.gpio.ptcpar.
//
#define GPIO_PAR_TIN2       (   0x0C )   // Bit  3 -  2 - DMA Timer Input 2
#define GPIO_PAR_DTOUT3     (   0x30 )   // Bit  5 -  4 - DMA Timer Output 3
#define GPIO_PAR_DTOUT2     (   0x03 )   // Bit  1 -  0 - DMA Timer Output 2
#define GPIO_PAR_TIN3       (   0xC0 )   // Bit  7 -  6 - DMA Timer Input 3

//
// For use with port TD pin assignment register: sim.gpio.ptdpar.
//
#define GPIO_PAR_TIN0       (   0x0C )   // Bit  3 -  2 - DMA Timer Input 0
#define GPIO_PAR_DTOUT1     (   0x30 )   // Bit  5 -  4 - DMA Timer Output 1
#define GPIO_PAR_DTOUT0     (   0x03 )   // Bit  1 -  0 - DMA Timer Output 0
#define GPIO_PAR_TIN1       (   0xC0 )   // Bit  7 -  6 - DMA Timer Input 1

//
// For use with GPTA system control register 1: sim.gpt[0].scr1.
//
#define GPIO_SCR_GPTA       (   0x80 )   // Bit       7 - GP Timer A [3:0]

//
// For use with GPTB system control register 1: sim.gpt[1].scr1.
//
#define GPIO_SCR_GPTB       (   0x80 )   // Bit       7 - GP Timer B [3:0]


////////////////////////////////////////////////////////////////////////////////
// GPIO Port Data Direction Register, Port Output Data Register, Port Pin Data/
// Set Data Register, and Port Clear Output Data Register Definitions. The
// following defined values are only for use on corresponding pins that are
// configured for GPIO.
//
// Port Data Direction Register (DDRn)
// Write: 0 = Input, 1 = Output
// Read: The current values in the register
//
// Port Output Data Register (PORTn)
// Write: 0 = Low, 1 = High
// Read: The current values in the register (not the port pin values)
//
// Port Pin Data/Set Data Register (PORTnP)
// Write: 0 = No Effect, 1 = High (for corresponding bits in PORTn)
// Read: The current state of the pins
//
// Port Clear Output Data Register (CLRn)
// Write: 0 = Low (for corresponding bits in PORTn), 1 = No Effect
// Read: Always return zeros
//

//
// For use with sim.gpio.ddre, sim.gpio.porte, sim.gpio.portep, and
// sim.gpio.clre.
//
#define GPIO_PIN_RW         (   0x10 )   // Bit 4 - Read / not Write
#define GPIO_PIN_OE         (   0x80 )   // Bit 7 - Output Enable
#define GPIO_PIN_TIP        (   0x01 )   // Bit 0 - Transfer in Progress
#define GPIO_PIN_TA         (   0x40 )   // Bit 6 - Transfer Acknowledge

//
// For use with sim.gpio.ddrj, sim.gpio.portj, sim.gpio.portjp, and
// sim.gpio.clrj.
//
#define GPIO_PIN_CS1        (   0x02 )   // Bit 1 - Chip Select #1
#define GPIO_PIN_CS2        (   0x04 )   // Bit 2 - Chip Select #2
#define GPIO_PIN_CS3        (   0x08 )   // Bit 3 - Chip Select #3

//
// For use with sim.gpio.ddrua, sim.gpio.portua, sim.gpio.portuap, and
// sim.gpio.clrua.
//
#define GPIO_PIN_URXD0      (   0x02 )   // Bit 1 - UART 0 - Receive
#define GPIO_PIN_UTXD0      (   0x01 )   // Bit 0 - UART 0 - Transmit
#define GPIO_PIN_URXD1      (   0x08 )   // Bit 3 - UART 1 - Receive
#define GPIO_PIN_UTXD1      (   0x04 )   // Bit 2 - UART 1 - Transmit

//
// For use with sim.gpio.ddrqs, sim.gpio.portqs, sim.gpio.portqsp, and
// sim.gpio.clrqs.
//
#define GPIO_PIN_SPI_CLK    (   0x04 )   // Bit 2 - SPI Clock
#define GPIO_PIN_SPI_CS3    (   0x40 )   // Bit 6 - SPI Chip Select 3
#define GPIO_PIN_SPI_DIN    (   0x02 )   // Bit 1 - SPI Data In
#define GPIO_PIN_SPI_DOUT   (   0x01 )   // Bit 0 - SPI Data Out
#define GPIO_PIN_SPI_CS0    (   0x08 )   // Bit 3 - SPI Chip Select 0
#define GPIO_PIN_SPI_CS2    (   0x20 )   // Bit 5 - SPI Chip Select 2
#define GPIO_PIN_SPI_CS1    (   0x10 )   // Bit 4 - SPI Chip Select 1

//
// For use with sim.gpio.ddras, sim.gpio.portas, sim.gpio.portasp, and
// sim.gpio.clras.
//
#define GPIO_PIN_SDA        (   0x02 )   // Bit 1 - I2C Serial Data
#define GPIO_PIN_CANRX      (   0x08 )   // Bit 3 - CAN - Receive
#define GPIO_PIN_SCL        (   0x01 )   // Bit 0 - I2C Serial Clock
#define GPIO_PIN_CANTX      (   0x04 )   // Bit 2 - CAN - Transmit

//
// For use with sim.gpio.ddrtc, sim.gpio.porttc, sim.gpio.porttcp, and
// sim.gpio.clrtc.
//
#define GPIO_PIN_TIN2       (   0x02 )   // Bit 1 - DMA Timer Input 2
#define GPIO_PIN_DTOUT3     (   0x04 )   // Bit 2 - DMA Timer Output 3
#define GPIO_PIN_DTOUT2     (   0x01 )   // Bit 0 - DMA Timer Output 2
#define GPIO_PIN_TIN3       (   0x08 )   // Bit 3 - DMA Timer Input 3

//
// For use with sim.gpio.ddrtd, sim.gpio.porttd, sim.gpio.porttdp, and
// sim.gpio.clrtd.
//
#define GPIO_PIN_TIN0       (   0x02 )   // Bit 1 - DMA Timer Input 0
#define GPIO_PIN_DTOUT1     (   0x04 )   // Bit 2 - DMA Timer Output 1
#define GPIO_PIN_DTOUT0     (   0x01 )   // Bit 0 - DMA Timer Output 0
#define GPIO_PIN_TIN1       (   0x08 )   // Bit 3 - DMA Timer Input 1

//
// For use with sim.qadc.ddrqa and sim.qadc.portqa. Note: PORTQA has the same
// write functionality as a GPIO PORTn register, but also has the read
// functionality of a PORTnP register (reads port pin values, not the values in
// the register).
//
#define GPIO_PIN_AN56       (   0x10 )   // Bit 4 - Analog I/O Channel 56
#define GPIO_PIN_AN53       (   0x02 )   // Bit 1 - Analog I/O Channel 53
#define GPIO_PIN_AN52       (   0x01 )   // Bit 0 - Analog I/O Channel 52
#define GPIO_PIN_AN55       (   0x08 )   // Bit 3 - Analog I/O Channel 55

//
// For use with sim.qadc.ddrqb and sim.qadc.portqb. Note: PORTQB has the same
// write functionality as a GPIO PORTn register, but also has the read
// functionality of a PORTnP register (reads port pin values, not the values in
// the register).
//
#define GPIO_PIN_AN3        (   0x08 )   // Bit 3 - Analog I/O Channel 3
#define GPIO_PIN_AN1        (   0x02 )   // Bit 1 - Analog I/O Channel 1
#define GPIO_PIN_AN2        (   0x04 )   // Bit 2 - Analog I/O Channel 2
#define GPIO_PIN_AN0        (   0x01 )   // Bit 0 - Analog I/O Channel 0

//
// For use with sim.eport.epddr, sim.eport.epdr, and sim.eport.eppdr.
// Note: EPDDR is similar to DDRn, EPDR is similar to PORTn, and EPPDR is
// similar to PORTnP.
//
#define GPIO_PIN_IRQ1       (   0x02 )   // Bit 1 - External Interrupt #1
#define GPIO_PIN_IRQ3       (   0x08 )   // Bit 3 - External Interrupt #3
#define GPIO_PIN_IRQ5       (   0x20 )   // Bit 5 - External Interrupt #5
#define GPIO_PIN_IRQ7       (   0x80 )   // Bit 7 - External Interrupt #7

//
// For use with sim.gpt[0].ddr and sim.gpt[0].port. Note: PORT has the same
// write functionality as a GPIO PORTn register, but also has the read
// functionality of a PORTnP register (reads port pin values, not the values in
// the register).
//
#define GPIO_PIN_GPTA3      (   0x08 )   // Bit 3 - General Purpose Timer A3
#define GPIO_PIN_GPTA2      (   0x04 )   // Bit 2 - General Purpose Timer A2
#define GPIO_PIN_GPTA1      (   0x02 )   // Bit 1 - General Purpose Timer A1
#define GPIO_PIN_GPTA0      (   0x01 )   // Bit 0 - General Purpose Timer A0

//
// For use with sim.gpt[1].ddr and sim.gpt[1].port. Note: PORT has the same
// write functionality as a GPIO PORTn register, but also has the read
// functionality of a PORTnP register (reads port pin values, not the values in
// the register).
//
#define GPIO_PIN_GPTB3      (   0x08 )   // Bit 3 - General Purpose Timer B3
#define GPIO_PIN_GPTB2      (   0x04 )   // Bit 2 - General Purpose Timer B2
#define GPIO_PIN_GPTB1      (   0x02 )   // Bit 1 - General Purpose Timer B1
#define GPIO_PIN_GPTB0      (   0x01 )   // Bit 0 - General Purpose Timer B0
